@@ -2,6 +2,8 @@ import logging
 from typing import List, Dict
 
 from openai import OpenAI
+from openai.types.beta.threads.run_submit_tool_outputs_params import ToolOutput
+
 from astra_assistants import patch
 from astra_assistants.astra_assistants_event_handler import AstraEventHandler
 from astra_assistants.tools.tool_interface import ToolInterface
@@ -9,14 +11,14 @@ from astra_assistants.tools.tool_interface import ToolInterface
 logger = logging.getLogger(__name__)
 
 class AssistantManager:
-    def __init__(self, instructions: str, tools: List[ToolInterface], cache: List[Dict[str, any]], model: str = "gpt-4o"):
+    def __init__(self, instructions: str, tools: List[ToolInterface], model: str = "gpt-4o", name: str = "managed_assistant"):
 
         self.client = patch(OpenAI())
         self.model = model
         self.instructions = instructions
         self.tools = tools
+        self.name = name
 
-        self.cache = cache
         self.assistant = self.create_assistant()
         self.thread = self.create_thread()
         print(f'assistant {self.assistant}')
@@ -38,7 +40,7 @@ class AssistantManager:
 
         # Create and return the assistant
         self.assistant = self.client.beta.assistants.create(
-            name="cass gpt",
+            name=self.name,
             instructions=self.instructions,
             model=self.model,
             tools=tool_functions
@@ -52,7 +54,7 @@ class AssistantManager:
         print("Thread generated:", thread)
         return thread
 
-    async def run_thread(self, tool, content):
+    async def run_thread(self, tool, content) -> ToolOutput:
         assistant = self.assistant
         event_handler = AstraEventHandler(self.client)
         event_handler.register_tool(tool)
@@ -73,11 +75,10 @@ class AssistantManager:
                 for part in stream.text_deltas:
                     text += part
 
-            # TODO: fix this hack for concurrency etc.
-            response = self.cache[len(self.cache)-1]
+            tool_call_results = event_handler.tool_call_results
 
-            print(response)
-            return response
+            print(tool_call_results)
+            return tool_call_results
         except Exception as e:
             print(e)
             raise e
\ No newline at end of file
